@@ -234,12 +234,20 @@ while (max > 0)
       serving_ratio = deficpct[count] / thispct;
       if (serving_ratio < serving_ratio_abacus[abacuscount] && serving_ratio * food_ptr->grams > 14) serving_ratio_abacus[abacuscount] = serving_ratio;
       }
+/*
      if (strstr(food_ptr->name,"DEHYD") != NULL) high_grams = 114;
+     if (strstr(food_ptr->name,"DEHYDRATED") != NULL) high_grams = 114;
      if (strstr(food_ptr->name,"DRY") != NULL) high_grams = 114;
      if (strstr(food_ptr->name,"FROZEN DSSRT") != NULL) high_grams = 114;
+*/
+     if (strstr(food_ptr->name,"DRY") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"FREEZE-DRIED") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"DEHYD") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"ALASKA NATIVE") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"AK NATIVE") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"NAVAJO") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"INST BRKFST PDR") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"INSTANT BREAKFAST") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"ENSURE") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"MEATLESS") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"MARGARINE") != NULL) high_grams = 14;
@@ -265,7 +273,7 @@ while (max > 0)
     totaldefic = 0;
     for (count = 0; count <= deficnuts; count++) 
      {
-     thispct = serving_ratio_abacus[abacuscount] * 100 * food_ptr->nutrient[DVMap[deficnut[count]+1]] / DV[DVMap[deficnut[count]+1]]; 
+     thispct = serving_ratio_abacus[abacuscount] * food_ptr->grams * food_ptr->nutrient[DVMap[deficnut[count]+1]] / DV[DVMap[deficnut[count]+1]]; 
      if (thispct > deficpct[count]) thispct = deficpct[count];
      deficpct[count] -= thispct;
      totaldefic += deficpct[count];
