@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 2005 Jim Jozwiak.
+    Copyright (C) 1996-2008 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 #include "meal.h"
 #include "options.h"
 #include "util.h"
-#include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -36,7 +35,7 @@ char nutdir1[]=".nutdb";
 char nutdir1[]=NUTDIR ;
 #endif
 
-char USDAjoined1[] = "sr17.nut";
+char USDAjoined1[] = "sr21.nut";
 char globalFOOD1[] = "FOOD_DES.txt";
 char globalNUT1[] = "NUT_DATA.txt";
 char globalWEIGHT1[] = "WEIGHT.txt";
@@ -46,6 +45,7 @@ char localNUT1[] = "NUT_DATA.txt";
 char localWEIGHT1[] = "WEIGHT.txt";
 char foodfile1[] = "food.db";
 char mealfile1[] = "meal.db";
+char mealexpfile1[] = "meal.exp";
 char theusualfile1[] = "theusual.db";
 char optionsfile1[] = "options.db";
 char localOPTIONS1[] = "OPTIONS.txt";
@@ -62,6 +62,7 @@ char localNUT[2000];
 char localWEIGHT[2000];
 char foodfile[2000];
 char mealfile[2000];
+char mealexpfile[2000];
 char theusualfile[2000];
 char optionsfile[2000];
 char localOPTIONS[2000];
@@ -100,7 +101,7 @@ void read_food_files()
 
 void read_joined_db(char *textfile) 
 {
-char buffer[700];
+char buffer[800];
 char *bufptr;
 char *fieldptr;
 int count, junk, foodcount = 0;
@@ -113,7 +114,7 @@ if ((fp = fopen(textfile,"rb")) == NULL)
  }
 printf("\nReading food file \"%s\"\n",textfile);
 printf("to create food database \"%s\"...\n",foodfile);
-while (fgets(buffer,700,fp) != NULL)
+while (fgets(buffer,800,fp) != NULL)
  {
  if ((new_food = malloc(sizeof(struct food))) == NULL)
   {
@@ -125,6 +126,10 @@ while (fgets(buffer,700,fp) != NULL)
  while (*bufptr != '^') bufptr++;
  *bufptr = '\0' ; bufptr++;
  new_food->ndb_no = atoi(fieldptr);
+ fieldptr = bufptr;
+ while (*bufptr != '^') bufptr++;
+ *bufptr = '\0' ; bufptr++;
+ new_food->fdgrp = atoi(fieldptr);
  fieldptr = new_food->name;
  while (*bufptr != '^')
   {
@@ -203,6 +208,7 @@ while (fgets(buffer,400,fp) != NULL)
    abort();
    }
   new_food->ndb_no = ndbno;
+  if (ndbno >= 99000) new_food->fdgrp = 0;
   for (count = 0; count < NUTRIENT_COUNT; count++) new_food->nutrient[count] = NoData;
   if (ndbno >= options.next_recipe) options.next_recipe = ndbno + 1;
   food_ptr = new_food;
@@ -687,7 +693,6 @@ fprintf(fp,"%d^%d^\n",CUSTOM,options.custom);
 fprintf(fp,"%d^%f^\n",PCPROTEIN,options.pcprotein);
 fprintf(fp,"%d^%f^\n",PCCARB,options.pccarb);
 fprintf(fp,"%d^%f^\n",PCSATFAT,options.pcsatfat);
-fprintf(fp,"%d^%f^\n",FATPROTRATIO,options.fatprotratio);
 fprintf(fp,"%d^%d^\n",NEXT_RECIPE,options.next_recipe);
 fprintf(fp,"%d^%d^\n",MEALSPERDAY,options.mealsperday);
 fprintf(fp,"%d^%d^\n",GRAMS,options.grams);
@@ -696,6 +701,10 @@ fprintf(fp,"%d^%f^\n",PROTCALPERGM,options.protcalpergm);
 fprintf(fp,"%d^%f^\n",CARBCALPERGM,options.carbcalpergm);
 fprintf(fp,"%d^%f^\n",FATCALPERGM,options.fatcalpergm);
 fprintf(fp,"%d^%f^\n",FATTYACIDFACTOR,options.fattyacidfactor);
+fprintf(fp,"%d^%f^\n",N6HUFA,options.n6hufa);
+fprintf(fp,"%d^%f^\n",EPADHAMAX,options.epadhamax);
+fprintf(fp,"%d^%d^\n",DEFANALANAL,options.defanalanal);
+fprintf(fp,"%d^%d^\n",DEFANALREC,options.defanalrec);
 for (i = 1; i <= DV_COUNT; i++)
  {
  switch (DVMap[i])
@@ -796,8 +805,6 @@ while (fgets(buffer,100,fp) != NULL)
                         break;
   case PCSATFAT       : options.pcsatfat = atof(valbuf1);
                         break;
-  case FATPROTRATIO   : options.fatprotratio = atof(valbuf1);
-                        break;
   case NEXT_RECIPE    : options.next_recipe = atoi(valbuf1);
                         break;
   case MEALSPERDAY    : options.mealsperday = atoi(valbuf1);
@@ -814,6 +821,14 @@ while (fgets(buffer,100,fp) != NULL)
                         break;
   case FATTYACIDFACTOR : options.fattyacidfactor = atof(valbuf1);
                         break;
+  case N6HUFA          : options.n6hufa = atof(valbuf1);
+                        break;
+  case EPADHAMAX       : options.epadhamax = atof(valbuf1);
+                        break;
+  case DEFANALANAL     : options.defanalanal = atoi(valbuf1);
+                        break;
+  case DEFANALREC      : options.defanalrec = atoi(valbuf1);
+                        break;
   case OPT_CHO_NONFIB : options.abnuts[CHO_NONFIB] = atof(valbuf1);
                         options.locknuts[CHO_NONFIB] = atoi(valbuf2);
                         break;
@@ -866,16 +881,17 @@ strcpy(subuser,sub);
  mkdir (nutdir, 0700 );
  sprintf(nutdirsubuser,"%s/%s","NUTDB",subuser);
  mkdir (nutdirsubuser, 0700 );
- sprintf(USDAjoined,"%s/%s","NUTSR17",USDAjoined1);
- sprintf(globalFOOD,"%s/%s","NUTSR17",globalFOOD1);
- sprintf(globalNUT,"%s/%s","NUTSR17",globalNUT1);
- sprintf(globalWEIGHT,"%s/%s","NUTSR17",globalWEIGHT1);
- sprintf(weightlib,"%s/%s","NUTSR17",weightlib1);
+ sprintf(USDAjoined,"%s/%s","NUTSR21",USDAjoined1);
+ sprintf(globalFOOD,"%s/%s","NUTSR21",globalFOOD1);
+ sprintf(globalNUT,"%s/%s","NUTSR21",globalNUT1);
+ sprintf(globalWEIGHT,"%s/%s","NUTSR21",globalWEIGHT1);
+ sprintf(weightlib,"%s/%s","NUTSR21",weightlib1);
  sprintf(localFOOD,"%s/%s/%s","NUTDB",subuser,localFOOD1);
  sprintf(localNUT,"%s/%s/%s","NUTDB",subuser,localNUT1);
  sprintf(localWEIGHT,"%s/%s/%s","NUTDB",subuser,localWEIGHT1);
  sprintf(foodfile,"%s/%s/%s","NUTDB",subuser,foodfile1);
  sprintf(mealfile,"%s/%s/%s","NUTDB",subuser,mealfile1);
+ sprintf(mealexpfile,"%s/%s/%s","NUTDB",subuser,mealexpfile1);
  sprintf(theusualfile,"%s/%s/%s","NUTDB",subuser,theusualfile1);
  sprintf(optionsfile,"%s/%s/%s","NUTDB",subuser,optionsfile1);
  sprintf(localOPTIONS,"%s/%s/%s","NUTDB",subuser,localOPTIONS1);
@@ -895,6 +911,7 @@ sprintf(localNUT,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localNUT1);
 sprintf(localWEIGHT,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localWEIGHT1);
 sprintf(foodfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,foodfile1);
 sprintf(mealfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,mealfile1);
+sprintf(mealexpfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,mealexpfile1);
 sprintf(theusualfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,theusualfile1);
 sprintf(optionsfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,optionsfile1);
 sprintf(localOPTIONS,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localOPTIONS1);
@@ -914,7 +931,7 @@ fclose(fp);
 majreleasedot = atoi(strtok(release_string,"."));
 minreleasedot = atoi(strtok(NULL,"."));
 remove(oldversionfile);
-if ((fp = fopen(versionfile,"rb")) == NULL);
+if ((fp = fopen(versionfile,"rb")) == NULL)
  {
  if ((fp = fopen(versionfile,"wb")) == NULL) return;
  fprintf(fp,"%d.%d",majreleasedot,minreleasedot);
@@ -940,6 +957,7 @@ int minrelease;
 if ((fp = fopen(versionfile,"rb")) == NULL) return 0;
 fread(&release_string,8,1,fp);
 fclose(fp);
+if (strstr(release_string,".") == NULL) return 0;
 majrelease = atoi(strtok(release_string,"."));
 minrelease = atoi(strtok(NULL,"."));
 return level > 0 ? minrelease : majrelease;
@@ -963,3 +981,16 @@ if ((block = fwrite(release_string,strlen(release_string)+1,1,fp)) != 1)
  }
 fclose(fp);
 }
+
+void auto_export_meals()
+{
+/* This is an "automatic" migration to the java version of NUT */
+struct meal *meal_ptr = &meal_root;
+if ((fp = fopen(mealexpfile,"wb")) == NULL) return;
+while (meal_ptr->next != NULL)
+ {
+ meal_ptr = meal_ptr->next;
+ fprintf(fp,"%s^%d^%d^%f\n",meal_ptr->meal_date,meal_ptr->meal,meal_ptr->ndb_no,meal_ptr->grams);
+ }
+fclose(fp);
+}
