@@ -137,12 +137,12 @@ DVBase[VITC] = 60;
 DVBase[FASAT] = 20;
 DVBase[CHOLE] = 300;
 DVBase[VITD] = 400;
-DVBase[LA] = 12;
-DVBase[AA] = 0.4;
+DVBase[LA] = 4.44;
+DVBase[AA] = 0.144;
 DVBase[OMEGA6] = DVBase[LA] + DVBase[AA];
-DVBase[ALA] = 2.22;
-DVBase[EPA] = 0.4;
-DVBase[DHA] = 0.4;
+DVBase[ALA] = 1.77;
+DVBase[EPA] = 0.30;
+DVBase[DHA] = 0.35;
 DVBase[OMEGA3] = DVBase[ALA] + DVBase[EPA] + DVBase[DHA];
 DVBase[FAPU] = DVBase[OMEGA6] + DVBase[OMEGA3];
 DVBase[FAMS] = 61.5 - DVBase[FASAT] - DVBase[FAPU];
@@ -652,7 +652,8 @@ switch (options.screen)
  h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
  o  = 902 * food_work.nutrient[FAT] * options.fattyacidfactor / food_work.nutrient[ENERC_KCAL] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3];
  n6 = (int) n6hufa(p3,p6,h3,h6,o,food_work.nutrient[ENERC_KCAL]);
- fprintf(fp,"Omega-6/3 Balance %2d/%2d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
+ if (options.n6hufa == 0 || (options.n6hufa < 90 && options.n6hufa > 15)) fprintf(fp,"Omega-6/3 Balance %2d/%2d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
+ else fprintf(fp,"\n");
  break;
  case 2 :
  fprintf(fp,"%-27s","Carbohydrates");
@@ -763,7 +764,8 @@ switch (options.screen)
  h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
  o  = 902 * food_work.nutrient[FAT] * options.fattyacidfactor / food_work.nutrient[ENERC_KCAL] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3];
  n6 = (int) n6hufa(p3,p6,h3,h6,o,food_work.nutrient[ENERC_KCAL]);               
- fprintf(fp,"Omega-6/3 Balance %2d/%2d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
+ if (options.n6hufa == 0 || (options.n6hufa < 90 && options.n6hufa > 15)) fprintf(fp,"Omega-6/3 Balance %2d/%2d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
+ else fprintf(fp,"\n");
  break;
  }
 }
@@ -1016,7 +1018,9 @@ return buffer;
 
 float n6hufa(float p3, float p6, float h3, float h6, float o, float c)
 {
-float pc6 = .0441, pc3 = .0555, co = 5, ks = .175, hi3 = .005, hc6 = .7, hc3 = 3;
+float pc6 = .0441, pc3 = .0555, co = 5, ks = .175, hc6 = .7, hc3 = 3;
+float hi3 = .005;
+/* float hi6 = .04; */
 float answer;
 /*
 printf("%f %f %f %f %f\n",p3,p6,h3,h6,o);
