@@ -29,7 +29,7 @@
 
 struct opt options;
 
-static float DefaultTarget = 64, DefaultEPADHA = 2.2;
+static float DefaultTarget = 55, DefaultEPADHA = 4.1;
 
 void initialize_options()
 {
@@ -151,7 +151,7 @@ while (1)
   if (options.locknuts[FAPU] != 1) printf("           3.  Change EPA+DHA maximum grams (currently %3.1f grams).\n\n",options.epadhamax == 0 ? DefaultEPADHA : options.epadhamax);
   if (options.locknuts[FAPU] != 1) spacer(8);
   else spacer(4);
-  printf("\nEnter new Omega-6 percentage (15-90):  ");
+  printf("\nEnter new Omega-6 percentage (15-90, 90 = off):  ");
   get_string(buf,127);
   tempfloat = atof(buf);
   if (tempfloat < 15 || tempfloat > 90) break;
@@ -601,19 +601,53 @@ if (options.n6hufa != 0)
  if (options.n6hufa < 15) options.n6hufa = 15;
  if (options.n6hufa > 90) options.n6hufa = 90;
  }
-
-if (options.epadhamax <= 0) epadhalimit = DefaultEPADHA;
-else epadhalimit = options.epadhamax;
-if (options.n6hufa != 0) target = options.n6hufa;
   
 /*
 DV[ALA] = food_work.nutrient[ALA];
 if (DV[ALA] <= 0) DV[ALA] = .00001;
 */
   
-  
 if (food_work.nutrient[ALA] > DV[ALA]) DV[ALA] = food_work.nutrient[ALA];
-  
+
+if (options.n6hufa == 90 || options.n6hufa == 15)
+ {
+ DV[OMEGA6] = food_work.nutrient[OMEGA6];
+ if (DV[OMEGA6] <= 0) DV[OMEGA6] = .00001;
+ options.abnuts[OMEGA6] = DV[OMEGA6];
+ DV[LA] = food_work.nutrient[LA];
+ if (DV[LA] <= 0) DV[LA] = .00001;
+ options.abnuts[LA] = DV[LA];
+ DV[AA] = food_work.nutrient[AA];
+ if (DV[AA] <= 0) DV[AA] = .00001;
+ options.abnuts[AA] = DV[AA];
+ DV[OMEGA3] = food_work.nutrient[OMEGA3];
+ if (DV[OMEGA3] <= 0) DV[OMEGA3] = .00001;
+ options.abnuts[OMEGA3] = DV[OMEGA3];
+ DV[ALA] = food_work.nutrient[ALA];
+ if (DV[ALA] <= 0) DV[ALA] = .00001;
+ options.abnuts[ALA] = DV[ALA];
+ DV[EPA] = food_work.nutrient[EPA];
+ if (DV[EPA] <= 0) DV[EPA] = .00001;
+ options.abnuts[EPA] = DV[EPA];
+ DV[DHA] = food_work.nutrient[DHA];
+ if (DV[DHA] <= 0) DV[DHA] = .00001;
+ options.abnuts[DHA] = DV[DHA];
+/*
+ if (options.epadhamax < options.abnuts[EPA] + options.abnuts[DHA])
+  {
+  temp = options.abnuts[EPA] + options.abnuts[DHA] - options.epadhamax;
+  temp1 = options.abnuts[EPA] / (options.abnuts[EPA] + options.abnuts[DHA]);
+  DV[EPA] = options.abnuts[EPA] -= temp * temp1;
+  DV[DHA] = options.abnuts[DHA] -= temp * (1 - temp1);
+  DV[OMEGA3] = options.abnuts[OMEGA3] -= temp;
+  }
+*/
+ return;
+ }
+
+if (options.epadhamax <= 0) epadhalimit = DefaultEPADHA;
+else epadhalimit = options.epadhamax;
+if (options.n6hufa != 0) target = options.n6hufa;
 
 options.abnuts[AA] = food_work.nutrient[AA];
 options.abnuts[LA] = food_work.nutrient[LA];
@@ -624,7 +658,7 @@ p6 = 902 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
 h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
 o  = 902 * food_work.nutrient[FAT] * options.fattyacidfactor / food_work.nutrient[ENERC_KCAL] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3];
 
-if (food_work.nutrient[EPA] > .02 || food_work.nutrient[DHA] > .02 || food_work.nutrient[AA] > .02) for (i = 1; i < 200000; i++)
+if (food_work.nutrient[EPA] > .01 || food_work.nutrient[DHA] > .01 || food_work.nutrient[AA] > .01) for (i = 1; i < 200000; i++)
  {
  temp = i * .001;
  h3 = 902 * temp / food_work.nutrient[ENERC_KCAL];
@@ -635,9 +669,17 @@ if (food_work.nutrient[EPA] > .02 || food_work.nutrient[DHA] > .02 || food_work.
  options.abnuts[OMEGA6] = food_work.nutrient[SHORT6] + food_work.nutrient[LONG6];
  options.abnuts[OMEGA3] = food_work.nutrient[SHORT3] + extra_ala + temp;
  temp -= food_work.nutrient[LONG3] - food_work.nutrient[EPA] - food_work.nutrient[DHA];
- if (food_work.nutrient[EPA] > 0 || food_work.nutrient[DHA] > 0) temp = temp / (food_work.nutrient[EPA] + food_work.nutrient[DHA]);
- options.abnuts[EPA] = food_work.nutrient[EPA] * temp;
- options.abnuts[DHA] = food_work.nutrient[DHA] * temp;
+ if (food_work.nutrient[EPA] > 0 || food_work.nutrient[DHA] > 0)
+  {
+  temp = temp / (food_work.nutrient[EPA] + food_work.nutrient[DHA]);
+  options.abnuts[EPA] = food_work.nutrient[EPA] * temp;
+  options.abnuts[DHA] = food_work.nutrient[DHA] * temp;
+  }
+ if (food_work.nutrient[EPA] <= 0 && food_work.nutrient[DHA] <= 0)
+  {
+  options.abnuts[EPA] = temp / 2;
+  options.abnuts[DHA] = temp / 2;
+  }
  if (options.abnuts[EPA] + options.abnuts[DHA] > epadhalimit)
   {
   temp = options.abnuts[EPA] + options.abnuts[DHA] - epadhalimit;
